@@ -1,4 +1,4 @@
-/* $Id: mountlist.h,v 1.21 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: mountlist.h,v 1.22 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -55,7 +55,8 @@ struct _glibtop_mountlist
 		size;			/* GLIBTOP_MOUNTLIST_SIZE	*/
 };
 
-#define glibtop_get_mountlist(mountlist,all_fs)	glibtop_get_mountlist_l(glibtop_global_server, mountlist, all_fs)
+glibtop_mountentry *
+glibtop_get_mountlist(glibtop_mountlist *buf, int all_fs);
 
 #define glibtop_get_mountlist_r		glibtop_get_mountlist_s
 
