@@ -1,4 +1,4 @@
-/* $Id: swap.h,v 1.24 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: swap.h,v 1.25 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -49,7 +49,8 @@ struct _glibtop_swap
 		pageout;	/* GLIBTOP_SWAP_PAGEOUT	*/
 };
 
-#define glibtop_get_swap(swap)	glibtop_get_swap_l(glibtop_global_server, swap)
+void
+glibtop_get_swap(glibtop_swap *buf);
 
 #if GLIBTOP_SUID_SWAP
 #define glibtop_get_swap_r		glibtop_get_swap_p
